@@ -114,18 +114,12 @@
 
   [probeLibrary setProbeMap: probeMap For: [finalSelf class]];
 
-  finalSelf->probeDisplay =
-    [probeDisplayManager createProbeDisplayFor: finalSelf];
+  [probeDisplayManager createProbeDisplayFor: finalSelf];
 
 
   return (finalSelf);
 }
 
--(void) drop {
-  [probeDisplay drop];
-  [super drop];
-}
-
 
 -(void) setCatalystMobilityFactor: (double) mobilityFactor {
   catalystMobilityFactor = mobilityFactor;
