@@ -21,7 +21,7 @@ ParticleManager *catalystMgr;
 
 AgentManager *bondMgr;
 
-SCLRandomBit *sclRandomBit;
+PRNG *prng;
 
 unsigned modelTime;
 
