@@ -46,8 +46,7 @@
 
   [probeLibrary setProbeMap: probeMap For: [finalSelf class]];
 
-  finalSelf->probeDisplay =
-    [probeDisplayManager createProbeDisplayFor: finalSelf];
+  [probeDisplayManager createProbeDisplayFor: finalSelf];
 
   return (finalSelf);
 }
@@ -59,9 +58,5 @@
   return self;
 }
    
--(void) drop {
-  [probeDisplay drop];
-  [super drop];
-}
 
 @end
