@@ -12,10 +12,11 @@
 
 static int major = 0;
 static int minor = 5;
+static int patch = 5;
 static char versionString[50]; // Defensive => longer than necessary...
 
 +(char *) getVersionString {
-  sprintf(versionString, "SCL v%d.%02d", major, minor);
+  sprintf(versionString, "SCL v%d.%02d.%02d", major, minor, patch);
   return versionString;
 }
 
@@ -27,6 +28,10 @@ static char versionString[50]; // Defensive => longer than necessary...
   return minor;
 }
 
++(int) getPatchVersion {
+  return patch;
+}
+
 +(void) printCopyright {
   printf("\n\n");
   printf([self getVersionString]);
