@@ -132,8 +132,7 @@
   WorldManager *finalSelf;
 
   finalSelf = [super createEnd];
-  finalSelf->probeDisplay =
-    [probeDisplayManager createProbeDisplayFor: finalSelf];
+  [probeDisplayManager createProbeDisplayFor: finalSelf];
 
   finalSelf->worldTime = 0;
   [Link setupProbeMap: [finalSelf getZone]];  // Has to be done *somewhere*...
@@ -143,7 +142,6 @@
 
 -(void) drop {
   [self dropWorld];
-  [probeDisplay drop];
   [super drop];
 }
 
@@ -290,9 +288,6 @@
     [worldDisplay drop];
     worldDisplay = nil;
 
-    [globalTkInterp eval: "destroy %s",
-      [[worldRaster getParent] getWidgetName]]; 
-      // Hack because Raster doesn't (yet) clean up on drop...
     [worldRaster drop];
     worldRaster = nil;
 
